<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/wordpress-platform
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Controller;

use JchOptimize\Core\Admin\Tasks;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
class BrowserCaching extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    public function __construct(?Input $input = null)
    {
        parent::__construct($input, null);
    }
    public function execute()
    {
        $expires = Tasks::leverageBrowserCaching();
        if ($expires === \false) {
            $this->logger->error(\__('Failed trying to add browser caching codes to the .htaccess file', 'jch-optimize'));
        } elseif ($expires === 'FILEDOESNTEXIST') {
            $this->logger->warning(\__('No .htaccess file were found in the root of this site', 'jch-optimize'));
        } elseif ($expires === 'CODEUPDATEDSUCCESS') {
            $this->logger->success(\__('The .htaccess file was updated successfully', 'jch-optimize'));
        } elseif ($expires === 'CODEUPDATEDFAIL') {
            $this->logger->error(\__('Failed to update the .htaccess file', 'jch-optimize'));
        } else {
            $this->logger->success(\__('Successfully added codes to the .htaccess file to promote browser caching', 'jch-optimize'));
        }
        wp_redirect('options-general.php?page=jch_optimize');
        exit;
    }
}
