<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/wordpress-platform
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Controller;

use JchOptimize\Core\Admin\Tasks;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
class DeleteBackups extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    public function __construct(?Input $input = null)
    {
        parent::__construct($input, null);
    }
    public function execute()
    {
        $mResult = Tasks::deleteBackupImages();
        if ($mResult === \false) {
            $this->logger->error(\__('Failed trying to delete backup images', 'jch-optimize'));
        } elseif ($mResult === 'BACKUPPATHDOESNTEXIST') {
            $this->logger->warning(\__('The folder containing backup images wasn\'t created yet. Try optimizing some images first.', 'jch-optimize'));
        } else {
            $this->logger->success(\__('Successfully deleted backup images', 'jch-optimize'));
        }
        wp_redirect('options-general.php?page=jch_optimize&tab=optimizeimages');
        exit;
    }
}
