<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/wordpress-platform
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Controller;

use JchOptimize\Core\Admin\Ajax\Ajax as AdminAjax;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
class OptimizeImage extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    public function __construct(?Input $input = null)
    {
        parent::__construct($input, null);
    }
    public function execute()
    {
        $status = $this->getInput()->get('status', null);
        if (\is_null($status)) {
            echo AdminAjax::getInstance('OptimizeImage')->run();
            die;
        } else {
            if ($status == 'success') {
                $dir = \rtrim($this->getInput()->get('dir', ''), '/') . '/';
                $cnt = $this->getInput()->get('cnt', '');
                $this->logger->success(\sprintf(\__('%1$d images optimized in %2$s', 'jch-optimize'), $cnt, $dir));
            } else {
                $msg = $this->getInput()->get('msg', '');
                $this->logger->error(\__('The Optimize Image function failed with message "' . $msg, 'jch-optimize'));
            }
            wp_redirect('options-general.php?page=jch_optimize&tab=optimizeimages');
            exit;
        }
    }
}
