<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/wordpress-platform
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Controller;

use JchOptimize\Model\PageCache as PageCacheModel;
use JchOptimize\Platform\Plugin;
use JchOptimize\Plugin\Admin;
use JchOptimize\View\PageCacheHtml;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Laminas\Paginator\Adapter\ArrayAdapter;
use _JchOptimizeVendor\Laminas\Paginator\Paginator;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
class PageCache extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    /**
     * @var PageCacheHtml
     */
    private $view;
    /**
     * @var PageCacheModel
     */
    private $model;
    public function __construct(PageCacheHtml $view, PageCacheModel $model, ?Input $input = null)
    {
        $this->view = $view;
        $this->model = $model;
        parent::__construct($input, null);
    }
    /**
     * @inheritDoc
     */
    public function execute()
    {
        if ($this->getInput()->get('action') == 'delete') {
            if ($this->getInput()->get('cid')) {
                $success = $this->model->delete($this->getInput()->get('cid'));
            } else {
                $success = \false;
            }
        }
        if ($this->getInput()->get('action') == 'deleteall') {
            $success = $this->model->deleteAll();
        }
        if (isset($success)) {
            if ($success) {
                $this->logger->success(\__('Page cache deleted successfully.'));
            } else {
                $this->logger->error(\__('Error deleting page cache.'));
            }
            wp_redirect('options-general.php?page=jch_optimize&tab=pagecache');
            exit;
        }
        if (!Plugin::getPluginParams()->get('cache_enable', '0')) {
            $this->logger->warning(\__('Page Cache is not enabled. Please enable it on the Dashboard or Configurations tab. You may also want to disable other page cache plugins.'));
            Admin::publishAdminNotices();
        }
        $limit = $this->model->getState()->get('list_limit', '20');
        $page = $this->getInput()->get('list_page', '1');
        $paginator = new Paginator(new ArrayAdapter($this->model->getItems()));
        $paginator->setCurrentPageNumber($page)->setItemCountPerPage($limit);
        $this->view->setData(['items' => $paginator, 'tab' => 'pagecache', 'paginator' => $paginator->getPages(), 'pageLink' => 'options-general.php?page=jch_optimize&tab=pagecache', 'adapter' => $this->model->getAdapterName(), 'httpRequest' => $this->model->isCaptureCacheEnabled()]);
        $this->view->loadResources();
        $this->view->renderStatefulElements($this->model->getState());
        echo $this->view->render();
    }
}
