<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/wordpress-platform
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Controller;

use JchOptimize\Core\Admin\Icons;
use JchOptimize\Model\Configure;
use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
class ToggleSetting extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    /**
     * @var Configure
     */
    private $model;
    public function __construct(Configure $model, ?Input $input = null)
    {
        $this->model = $model;
        parent::__construct($input, null);
    }
    public function execute()
    {
        $setting = $this->getInput()->get('setting');
        $this->model->toggleSetting($setting);
        $currentSettingValue = $this->model->getState()->get($setting);
        if ($setting == 'integrated_page_cache_enable') {
            $currentSettingValue = \JchOptimize\Platform\Utility::isPageCacheEnabled($this->model->getState());
        }
        $class = $currentSettingValue ? 'enabled' : 'disabled';
        $class2 = '';
        $auto = \false;
        if ($setting == 'pro_remove_unused_css') {
            $class2 = $this->model->getState()->get('optimizeCssDelivery_enable') ? 'enabled' : 'disabled';
        }
        if ($setting == 'optimizeCssDelivery_enable') {
            $class2 = $this->model->getState()->get('pro_remove_unused_css') ? 'enabled' : 'disabled';
        }
        if ($setting == 'combine_files_enable' && $currentSettingValue) {
            $auto = $this->getEnabledAutoSetting();
        }
        echo \json_encode(['class' => $class, 'class2' => $class2, 'auto' => $auto]);
        exit;
    }
    private function getEnabledAutoSetting()
    {
        $autoSettingsMap = Icons::autoSettingsArrayMap();
        $autoSettingsInitialized = \array_map(function ($a) {
            return '0';
        }, $autoSettingsMap);
        $currentAutoSettings = \array_intersect_key($this->model->getState()->toArray(), $autoSettingsInitialized);
        //order array
        $orderedCurrentAutoSettings = \array_merge($autoSettingsInitialized, $currentAutoSettings);
        $autoSettings = ['minimum', 'intermediate', 'average', 'deluxe', 'premium', 'optimum'];
        for ($j = 0; $j < 6; $j++) {
            if (\array_values($orderedCurrentAutoSettings) === \array_column($autoSettingsMap, 's' . ($j + 1))) {
                return $autoSettings[$j];
            }
        }
        //No auto setting configured
        return \false;
    }
}
